@@ -1,17 +1,24 @@
-/// The plotting context and more stuff
+/*!
+The high-level chartting utils. `ChartBuilder` can be used to create a `ChartContext`.
+
+We are able to draw multiple series in the chart.
+A chart can be build on top of any drawing area based on a pixel coordinate.
+*/
+
 use std::borrow::Borrow;
 use std::fmt::Debug;
 /// The abstraction of a chart
 use std::marker::PhantomData;
 use std::ops::Range;
 
+use crate::coord::{CoordTranslate, MeshLine, Ranged, RangedCoord, Shift};
+use crate::drawing::backend::BackendCoord;
 use crate::drawing::backend::DrawingBackend;
-use crate::drawing::coord::{CoordTranslate, MeshLine, Ranged, RangedCoord, Shift};
 use crate::drawing::{DrawingArea, DrawingAreaErrorKind};
 use crate::element::{Drawable, PointCollection, Rectangle};
 use crate::style::{FontDesc, Mixable, RGBColor, ShapeStyle, TextStyle};
 
-/// The helper object to create a chart
+/// The helper object to create a chart context, which is used for the high-level plotting
 pub struct ChartBuilder<'a, DB: DrawingBackend> {
     x_label_size: u32,
     y_label_size: u32,
@@ -30,6 +37,7 @@ impl<'a, DB: DrawingBackend> ChartBuilder<'a, DB> {
         };
     }
 
+    /// Set the margin size of the chart
     pub fn set_margin(&mut self, size: u32) -> &mut Self {
         if self.titled_area.is_some() {
             return self;
@@ -39,13 +47,13 @@ impl<'a, DB: DrawingBackend> ChartBuilder<'a, DB> {
         return self;
     }
 
-    /// Set the size of X label
+    /// Set the size of X label area
     pub fn set_x_label_size(&mut self, size: u32) -> &mut Self {
         self.x_label_size = size;
         return self;
     }
 
-    /// Set the size of the Y label
+    /// Set the size of the Y label area
     pub fn set_y_label_size(&mut self, size: u32) -> &mut Self {
         self.y_label_size = size;
         return self;
@@ -69,7 +77,7 @@ impl<'a, DB: DrawingBackend> ChartBuilder<'a, DB> {
         return self;
     }
 
-    /// Builder the chart
+    /// Builder the chart with a ranged coordinate system
     pub fn build_ranged<XR: Ranged, YR: Ranged, X: Into<XR>, Y: Into<YR>>(
         &mut self,
         x_spec: X,
@@ -126,6 +134,7 @@ pub struct ChartContext<DB: DrawingBackend, CT: CoordTranslate> {
     drawing_area: DrawingArea<DB, CT>,
 }
 
+/// The struct that is used for tracking the configuration of a mesh of any chart
 pub struct MeshStyle<'a, X: Ranged, Y: Ranged, DB>
 where
     DB: DrawingBackend,
@@ -147,31 +156,37 @@ where
     Y: Ranged,
     DB: DrawingBackend,
 {
+    /// Set how many labels for the X axis
     pub fn x_labels(&mut self, value: usize) -> &mut Self {
         self.n_x_labels = value;
         return self;
     }
 
+    /// Set how many label for the Y axis
     pub fn y_labels(&mut self, value: usize) -> &mut Self {
         self.n_y_labels = value;
         return self;
     }
 
+    /// Set the style for the coarse grid
     pub fn line_style_1(&mut self, style: &'a ShapeStyle<'a>) -> &mut Self {
         self.line_style_1 = Some(style);
         return self;
     }
 
+    /// Set the style for the fine grid
     pub fn line_style_2(&mut self, style: &'a ShapeStyle<'a>) -> &mut Self {
         self.line_style_2 = Some(style);
         return self;
     }
 
+    /// Set the style of the label text
     pub fn label_style(&mut self, style: &'a TextStyle<'a>) -> &mut Self {
         self.label_style = Some(style);
         return self;
     }
 
+    /// Set the formatter function for the X label text
     pub fn x_label_formatter(
         &mut self,
         fmt: &'static dyn Fn(&X::ValueType) -> String,
@@ -180,6 +195,7 @@ where
         return self;
     }
 
+    /// Set the formatter function for the Y label text
     pub fn y_label_formatter(
         &mut self,
         fmt: &'static dyn Fn(&Y::ValueType) -> String,
@@ -188,6 +204,7 @@ where
         return self;
     }
 
+    /// Draw the configured mesh on the target plot
     pub fn draw(&mut self) -> Result<(), DrawingAreaErrorKind<DB::ErrorType>> {
         let mut target = None;
         std::mem::swap(&mut target, &mut self.target);
@@ -221,6 +238,13 @@ where
                 .unwrap_or(&default_mesh_style_2);
 
         target.draw_mesh(
+            (self.n_y_labels * 10, self.n_x_labels * 10),
+            mesh_style_2,
+            label_style,
+            |_| None,
+        )?;
+
+        return target.draw_mesh(
             (self.n_y_labels, self.n_x_labels),
             mesh_style_1,
             label_style,
@@ -228,13 +252,6 @@ where
                 MeshLine::XMesh(_, _, v) => Some((self.format_x)(v)),
                 MeshLine::YMesh(_, _, v) => Some((self.format_y)(v)),
             },
-        )?;
-
-        return target.draw_mesh(
-            (self.n_y_labels * 10, self.n_x_labels * 10),
-            mesh_style_2,
-            label_style,
-            |_| None,
         );
     }
 }
@@ -247,6 +264,8 @@ impl<
         Y: Ranged<ValueType = YT>,
     > ChartContext<DB, RangedCoord<X, Y>>
 {
+    /// Initialize a mesh configuration object and mesh drawing can be finalized by calling
+    /// the function `MeshStyle::draw`
     pub fn configure_mesh(&mut self) -> MeshStyle<X, Y, DB> {
         return MeshStyle {
             n_x_labels: 10,
@@ -285,6 +304,10 @@ impl<DB: DrawingBackend, X: Ranged, Y: Ranged> ChartContext<DB, RangedCoord<X, Y
         return self.series_area.as_ref().unwrap().draw(&element);
     }
 
+    pub fn backend_coord(&self, coord: &(X::ValueType, Y::ValueType)) -> BackendCoord {
+        return self.drawing_area.map_coordinate(coord);
+    }
+
     /// Draw a series
     pub fn draw_series<E, R, S>(&self, series: S) -> Result<(), DrawingAreaErrorKind<DB::ErrorType>>
     where
