@@ -1,6 +1,6 @@
 /// The abstraction of a drawing area
 use super::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
-use super::coord::{CoordTranslate, MeshLine, Ranged, RangedCoord, Shift};
+use crate::coord::{CoordTranslate, MeshLine, Ranged, RangedCoord, Shift};
 use crate::element::{Drawable, PointCollection};
 use crate::style::{Color, TextStyle};
 
@@ -90,10 +90,16 @@ impl<DB: DrawingBackend, CT: CoordTranslate + Clone> Clone for DrawingArea<DB, C
     }
 }
 
+/// The error description of any drawing area API
 #[derive(Debug)]
 pub enum DrawingAreaErrorKind<E: Error> {
+    /// The error is due to drawing backend failure
     BackendError(DrawingErrorKind<E>),
+    /// We are not able to get the mutable reference of the backend,
+    /// which indicates the drawing backend is current used by other
+    /// drawing operation
     SharingError,
+    /// The error caused by invalid layout
     LayoutError,
 }
 
@@ -148,10 +154,12 @@ impl<DB: DrawingBackend, X: Ranged, Y: Ranged> DrawingArea<DB, RangedCoord<X, Y>
         });
     }
 
+    /// Get the range of X of the guest coordinate for current drawing area
     pub fn get_x_range(&self) -> Range<X::ValueType> {
         return self.coord.get_x_range();
     }
 
+    /// Get the range of Y of the guest coordinate for current drawing area
     pub fn get_y_range(&self) -> Range<Y::ValueType> {
         return self.coord.get_y_range();
     }
@@ -233,6 +241,11 @@ impl<DB: DrawingBackend, CT: CoordTranslate> DrawingArea<DB, CT> {
         });
         return self.backend_ops(move |b| element.draw(backend_coords, b));
     }
+
+    /// Map coordinate to the backend coordinate
+    pub fn map_coordinate(&self, coord: &CT::From) -> BackendCoord {
+        return self.coord.translate(coord);
+    }
 }
 
 impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
@@ -319,6 +332,7 @@ impl<DB: DrawingBackend> DrawingArea<DB, Shift> {
             .collect();
     }
 
+    /// Draw a title of the drawing area and return the remaining drawing area
     pub fn titled<'a, S: Into<TextStyle<'a>>>(
         &self,
         text: &str,
