@@ -95,6 +95,17 @@ pub trait DrawingBackend {
         color: &C,
         fill: bool,
     ) -> Result<(), DrawingErrorKind<Self::ErrorType>> {
+        let (upper_left, bottom_right) = (
+            (
+                upper_left.0.min(bottom_right.0),
+                upper_left.1.min(bottom_right.1),
+            ),
+            (
+                upper_left.0.max(bottom_right.0),
+                upper_left.1.max(bottom_right.1),
+            ),
+        );
+
         if fill {
             if bottom_right.0 - upper_left.0 < bottom_right.1 - upper_left.1 {
                 for x in upper_left.0..=bottom_right.0 {
